@@ -8,7 +8,7 @@ from ..machine_topics import MACHINE_EVENTS, MACHINE_INPUT_TOPIC
 from ..message import Headers
 from ..config import KAFKA_SERVER_URL
 from ..simulation.update_message_types import SetMachineMessage, UpdateMessage
-from src.ml_pipe_core.event_utls.consumer import consume
+from ..event_utls.consumer import consume
 
 _logger = init_logger(__name__)
 
